@@ -10,7 +10,7 @@ use std::{
 use auditable_serde::{DependencyKind, VersionInfo};
 use cargo_metadata::{
     camino::{Utf8Path, Utf8PathBuf},
-    Artifact,
+    Artifact, TargetKind,
 };
 
 // Path to cargo-auditable binary under test
@@ -104,7 +104,7 @@ where
                     .target
                     .kind
                     .iter()
-                    .any(|kind| kind.as_str() == "cdylib")
+                    .any(|kind| *kind == TargetKind::CDyLib)
                 {
                     // Detect files with .so (Linux), .dylib (Mac) and .dll (Windows) extensions
                     artifact
@@ -175,7 +175,7 @@ fn test_cargo_auditable_workspaces_inner(sbom: bool) {
     let bins = run_cargo_auditable(&workspace_cargo_toml, &[], &[], sbom);
     eprintln!("Test fixture binary map: {bins:?}");
     // No binaries for library_crate
-    assert!(bins.get("library_crate").is_none());
+    assert!(!bins.contains_key("library_crate"));
 
     // binary_and_cdylib_crate
     let binary_and_cdylib_crate_bins = bins.get("binary_and_cdylib_crate").unwrap();
